@@ -5,6 +5,7 @@ import plyer
 import os.path
 import time
 import sqlite3
+import random
 
 import RNS.vendor.umsgpack as msgpack
 import RNS.Interfaces.Interface as Interface
@@ -71,6 +72,10 @@ class SidebandCore():
     PERIODIC_JOBS_INTERVAL = 60
     PERIODIC_SYNC_RETRY = 360
 
+    IF_CHANGE_ANNOUNCE_MIN_INTERVAL = 15   # In seconds
+    AUTO_ANNOUNCE_RANDOM_MIN        = 90   # In minutes
+    AUTO_ANNOUNCE_RANDOM_MAX        = 480  # In minutes
+
     aspect_filter = "lxmf.delivery"
     def received_announce(self, destination_hash, announced_identity, app_data):
         # Add the announce to the directory announce
@@ -122,11 +127,15 @@ class SidebandCore():
         self.identity_path = self.app_dir+"/app_storage/primary_identity"
         self.db_path       = self.app_dir+"/app_storage/sideband.db"
         self.lxmf_storage  = self.app_dir+"/app_storage/"
+        self.log_dir       = self.app_dir+"/app_storage/"
         self.tmp_dir       = self.app_dir+"/app_storage/tmp"
         self.exports_dir   = self.app_dir+"/exports"
         
         self.first_run     = True
         self.saving_configuration = False
+        self.last_lxmf_announce = 0
+        self.last_if_change_announce = 0
+        self.next_auto_announce = time.time() + 60*(random.random()*(SidebandCore.AUTO_ANNOUNCE_RANDOM_MAX-SidebandCore.AUTO_ANNOUNCE_RANDOM_MIN))
 
         self.getstate_cache = {}
 
@@ -137,6 +146,9 @@ class SidebandCore():
                 self.__load_config()
                 self.first_run = False
 
+            if self.config["debug"]:
+                self.log_verbose = True
+
             if not os.path.isdir(self.tmp_dir):
                 os.makedirs(self.tmp_dir)
             else:
@@ -203,10 +215,11 @@ class SidebandCore():
 
         self.config = {}
         # Settings
+        self.config["debug"] = False
         self.config["display_name"] = "Anonymous Peer"
         self.config["notifications_on"] = True
         self.config["dark_ui"] = False
-        self.config["start_announce"] = False
+        self.config["start_announce"] = True
         self.config["propagation_by_default"] = False
         self.config["home_node_as_broadcast_repeater"] = False
         self.config["send_telemetry_to_home_node"] = False
@@ -260,6 +273,7 @@ class SidebandCore():
         self.config["hw_rnode_beaconinterval"] = None
         self.config["hw_rnode_beacondata"] = None
         self.config["hw_rnode_bt_device"] = None
+        self.config["hw_rnode_bluetooth"] = False
         self.config["hw_modem_baudrate"] = 57600
         self.config["hw_modem_databits"] = 8
         self.config["hw_modem_stopbits"] = 1
@@ -299,6 +313,8 @@ class SidebandCore():
         config_file.close()
 
         # Migration actions from earlier config formats
+        if not "debug" in self.config:
+            self.config["debug"] = False
         if not "dark_ui" in self.config:
             self.config["dark_ui"] = True
         if not "lxmf_periodic_sync" in self.config:
@@ -448,9 +464,6 @@ class SidebandCore():
                 self.config["last_lxmf_propagation_node"] = dest
                 self.message_router.set_outbound_propagation_node(dest)
                 
-                if not self.is_service:
-                    self.owner_app.root.ids.settings_propagation_node_address.text = RNS.hexrep(dest, delimit=False)
-
                 RNS.log("Active propagation node set to: "+RNS.prettyhexrep(dest))
                 self.__save_config()
             except Exception as e:
@@ -1223,6 +1236,9 @@ class SidebandCore():
     def lxmf_announce(self):
         if self.is_standalone or self.is_service:
             self.lxmf_destination.announce()
+            self.last_lxmf_announce = time.time()
+            self.next_auto_announce = time.time() + 60*(random.random()*(SidebandCore.AUTO_ANNOUNCE_RANDOM_MAX-SidebandCore.AUTO_ANNOUNCE_RANDOM_MIN))
+            RNS.log("Next auto announce in "+RNS.prettytime(self.next_auto_announce-time.time()), RNS.LOG_DEBUG)
             self.setstate("wants.announce", False)
         else:
             self.setstate("wants.announce", True)
@@ -1254,7 +1270,32 @@ class SidebandCore():
             while True:
                 time.sleep(SidebandCore.SERVICE_JOB_INTERVAL)
                 now = time.time()
-                if self.getstate("wants.announce"):
+
+                announce_wanted = self.getstate("wants.announce")
+                if self.config["start_announce"] == True:
+                    needs_if_change_announce = False
+                    for interface in RNS.Transport.interfaces:
+                        if hasattr(interface, "was_online"):
+                            if not interface.was_online and interface.online:
+                                RNS.log("The interface "+str(interface)+" became available", RNS.LOG_DEBUG)
+                                needs_if_change_announce = True
+
+                        interface.was_online = interface.online
+
+                    if needs_if_change_announce and time.time() > self.last_if_change_announce+SidebandCore.IF_CHANGE_ANNOUNCE_MIN_INTERVAL:
+                        announce_wanted = True
+                        self.last_if_change_announce = time.time()
+
+                    if time.time() > self.next_auto_announce:
+                        announce_wanted = True
+
+                if hasattr(self, "interface_rnode") and self.interface_rnode != None:
+                    if self.config["hw_rnode_bluetooth"]:
+                        self.interface_rnode.allow_bluetooth = True
+                    else:
+                        self.interface_rnode.allow_bluetooth = False
+
+                if announce_wanted:
                     self.lxmf_announce()
 
                 if self.getstate("wants.bt_on"):
@@ -1296,8 +1337,11 @@ class SidebandCore():
                     else:
                         if hasattr(self.owner_app, "usb_devices") and self.owner_app.usb_devices != None:
                             if len(self.owner_app.usb_devices) > 0:
-                                target_port = self.owner_app.usb_devices[0]["port"]
-                                RNS.Interfaces.Android.RNodeInterface.RNodeInterface.bluetooth_control(port=target_port, pairing_mode = True)
+                                try:
+                                    target_port = self.owner_app.usb_devices[0]["port"]
+                                    RNS.Interfaces.Android.RNodeInterface.RNodeInterface.bluetooth_control(port=target_port, pairing_mode = True)
+                                except Exception as e:
+                                    self.setstate("hardware_operation.error", "An error ocurred while trying to communicate with the device. Please make sure that Sideband has been granted permissions to access the device.\n\nThe reported error was:\n\n[i]"+str(e)+"[/i]")                
                             else:
                                 RNS.log("Could not execute RNode Bluetooth control command, no USB devices available", RNS.LOG_ERROR)
                     self.setstate("executing.bt_pair", False)
@@ -1388,6 +1432,15 @@ class SidebandCore():
         self.reticulum = RNS.Reticulum(configdir=self.rns_configdir, loglevel=selected_level)
 
         if RNS.vendor.platformutils.get_platform() == "android":
+            # TODO: Just log to console for, but add option to export log
+            # files at some point.
+            # if self.config["debug"]:
+            #     self.reticulum.logdest = RNS.LOG_FILE
+            #     if not self.reticulum.is_connected_to_shared_instance:
+            #         self.reticulum.logfile = self.log_dir+"sideband_service.log"
+            #     else:
+            #         self.reticulum.logfile = self.log_dir+"sideband_core.log"
+
             if not self.reticulum.is_connected_to_shared_instance:
                 RNS.log("Running as master or standalone instance, adding interfaces")
                 
@@ -1554,81 +1607,81 @@ class SidebandCore():
                             # TODO: Add more intelligent selection here
                             target_device = self.owner_app.usb_devices[0]
 
-                        if target_device or self.config["hw_rnode_bluetooth"]:
-                            if target_device != None:
-                                target_port = target_device["port"]
-                            else:
-                                target_port = None
+                        # if target_device or self.config["hw_rnode_bluetooth"]:
+                        if target_device != None:
+                            target_port = target_device["port"]
+                        else:
+                            target_port = None
+                    
+                        bt_device_name = None
+                        rnode_allow_bluetooth = False
+                        if self.getpersistent("permissions.bluetooth"):
+                            if self.config["hw_rnode_bluetooth"]:
+                                RNS.log("Allowing RNode bluetooth", RNS.LOG_DEBUG)
+                                rnode_allow_bluetooth = True
+                                if self.config["hw_rnode_bt_device"] != None:
+                                    bt_device_name = self.config["hw_rnode_bt_device"]
 
-                            bt_device_name = None
-                            rnode_allow_bluetooth = False
-                            if self.getpersistent("permissions.bluetooth"):
-                                if self.config["hw_rnode_bluetooth"]:
-                                    RNS.log("Allowing RNode bluetooth", RNS.LOG_DEBUG)
-                                    rnode_allow_bluetooth = True
-                                    if self.config["hw_rnode_bt_device"] != None:
-                                        bt_device_name = self.config["hw_rnode_bt_device"]
-
-                                else:
-                                    RNS.log("Disallowing RNode bluetooth since config is disabled", RNS.LOG_DEBUG)
-                                    rnode_allow_bluetooth = False
                             else:
-                                RNS.log("Disallowing RNode bluetooth due to missing permission", RNS.LOG_DEBUG)
+                                RNS.log("Disallowing RNode bluetooth since config is disabled", RNS.LOG_DEBUG)
                                 rnode_allow_bluetooth = False
+                        else:
+                            RNS.log("Disallowing RNode bluetooth due to missing permission", RNS.LOG_DEBUG)
+                            rnode_allow_bluetooth = False
 
+                        if self.config["connect_rnode_ifac_netname"] == "":
+                            ifac_netname = None
+                        else:
+                            ifac_netname = self.config["connect_rnode_ifac_netname"]
 
+                        if self.config["connect_rnode_ifac_passphrase"] == "":
+                            ifac_netkey = None
+                        else:
+                            ifac_netkey = self.config["connect_rnode_ifac_passphrase"]
 
-                            if self.config["connect_rnode_ifac_netname"] == "":
-                                ifac_netname = None
-                            else:
-                                ifac_netname = self.config["connect_rnode_ifac_netname"]
+                        rnodeinterface = RNS.Interfaces.Android.RNodeInterface.RNodeInterface(
+                                RNS.Transport,
+                                "RNodeInterface",
+                                target_port,
+                                frequency = self.config["hw_rnode_frequency"],
+                                bandwidth = self.config["hw_rnode_bandwidth"],
+                                txpower = self.config["hw_rnode_tx_power"],
+                                sf = self.config["hw_rnode_spreading_factor"],
+                                cr = self.config["hw_rnode_coding_rate"],
+                                flow_control = None,
+                                id_interval = self.config["hw_rnode_beaconinterval"],
+                                id_callsign = self.config["hw_rnode_beacondata"],
+                                allow_bluetooth = rnode_allow_bluetooth,
+                                target_device_name = bt_device_name,
+                            )
 
-                            if self.config["connect_rnode_ifac_passphrase"] == "":
-                                ifac_netkey = None
-                            else:
-                                ifac_netkey = self.config["connect_rnode_ifac_passphrase"]
+                        rnodeinterface.OUT = True
 
-                            rnodeinterface = RNS.Interfaces.Android.RNodeInterface.RNodeInterface(
-                                    RNS.Transport,
-                                    "RNodeInterface",
-                                    target_port,
-                                    frequency = self.config["hw_rnode_frequency"],
-                                    bandwidth = self.config["hw_rnode_bandwidth"],
-                                    txpower = self.config["hw_rnode_tx_power"],
-                                    sf = self.config["hw_rnode_spreading_factor"],
-                                    cr = self.config["hw_rnode_coding_rate"],
-                                    flow_control = None,
-                                    id_interval = self.config["hw_rnode_beaconinterval"],
-                                    id_callsign = self.config["hw_rnode_beacondata"],
-                                    allow_bluetooth = rnode_allow_bluetooth,
-                                    target_device_name = bt_device_name,
-                                )
+                        if RNS.Reticulum.transport_enabled():
+                            if_mode = Interface.Interface.MODE_FULL
+                            if self.config["connect_ifmode_rnode"] == "gateway":
+                                if_mode = Interface.Interface.MODE_GATEWAY
+                            elif self.config["connect_ifmode_rnode"] == "access point":
+                                if_mode = Interface.Interface.MODE_ACCESS_POINT
+                            elif self.config["connect_ifmode_rnode"] == "roaming":
+                                if_mode = Interface.Interface.MODE_ROAMING
+                            elif self.config["connect_ifmode_rnode"] == "boundary":
+                                if_mode = Interface.Interface.MODE_BOUNDARY
+                        else:
+                            if_mode = None
+                            
+                        self.reticulum._add_interface(rnodeinterface, mode = if_mode, ifac_netname = ifac_netname, ifac_netkey = ifac_netkey)
+                        self.interface_rnode = rnodeinterface
 
-                            rnodeinterface.OUT = True
+                        if rnodeinterface != None:
+                            if len(rnodeinterface.hw_errors) > 0:
+                                self.setpersistent("startup.errors.rnode", rnodeinterface.hw_errors[0])
 
-                            if RNS.Reticulum.transport_enabled():
-                                if_mode = Interface.Interface.MODE_FULL
-                                if self.config["connect_ifmode_rnode"] == "gateway":
-                                    if_mode = Interface.Interface.MODE_GATEWAY
-                                elif self.config["connect_ifmode_rnode"] == "access point":
-                                    if_mode = Interface.Interface.MODE_ACCESS_POINT
-                                elif self.config["connect_ifmode_rnode"] == "roaming":
-                                    if_mode = Interface.Interface.MODE_ROAMING
-                                elif self.config["connect_ifmode_rnode"] == "boundary":
-                                    if_mode = Interface.Interface.MODE_BOUNDARY
-                            else:
-                                if_mode = None
-                                
-                            self.reticulum._add_interface(rnodeinterface, mode = if_mode, ifac_netname = ifac_netname, ifac_netkey = ifac_netkey)
-                            self.interface_rnode = rnodeinterface
-
-                            if rnodeinterface != None:
-                                if len(rnodeinterface.hw_errors) > 0:
-                                    self.setpersistent("startup.errors.rnode", rnodeinterface.hw_errors[0])
-
-                            if self.interface_rnode.online:
-                                self.interface_rnode.display_image(sideband_fb_data)
-                                self.interface_rnode.enable_external_framebuffer()
+                        if self.interface_rnode.online:
+                            self.interface_rnode.display_image(sideband_fb_data)
+                            self.interface_rnode.enable_external_framebuffer()
+                        else:
+                            self.interface_rnode.last_imagedata = sideband_fb_data
 
                     except Exception as e:
                         RNS.log("Error while adding RNode Interface. The contained exception was: "+str(e))
